// Water bodies dataset
const cityData = {
  name: 'Locations',
  children: [
    {
      name: 'Metropolis',
      children: [
        { name: 'New York' },
        { name: 'Los Angeles' },
        { name: 'Chicago' },
        { name: 'Houston' },
        { name: 'Philadelphia' },
      ],
    },
    {
      name: 'Urban Centers',
      children: [
        { name: 'Phoenix' },
        { name: 'San Antonio' },
        { name: 'San Diego' },
      ],
    },
    {
      name: 'Rural Centers',
      children: [
        { name: 'Greenfield' },
        { name: 'Springfield' },
        { name: 'Oakwood' },
      ],
    },
  ],
};

// Define width, height, and margin of the tree
const margin = {
  top: 5,
  right: 140,
  bottom: 10,
  left: 300,
};
const width = 960 - margin.left - margin.right;
const height = 500 - margin.top - margin.bottom;

const svg = d3
  .select('#tree-svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

const tree = d3.tree().size([height, width]);

const root = d3.hierarchy(cityData);
const nodes = tree(root);

// Define color scale for different levels
const colorScale = d3.scaleOrdinal(d3.schemeCategory10);

const link = svg
  .selectAll('.link')
  .data(root.links())
  .enter()
  .append('path')
  .attr('class', 'link')
  .attr(
    'd',
    d3
      .linkHorizontal()
      .x((d) => d.y)
      .y((d) => d.x),
  )
  .style('stroke', (d, i) => colorScale(d.source.depth)); // Assign color based on source node depth

const node = svg
  .selectAll('.node')
  .data(nodes.descendants())
  .enter()
  .append('g')
  .attr('class', 'node')
  .attr(
    'transform',
    (d) => 'translate(' + d.y + ',' + d.x + ')',
  );

node
  .append('circle')
  .attr('r', 5)
  .style('fill', (d) => colorScale(d.depth)); // Assign color based on node depth

node
  .append('text')
  .attr('dy', '0.31em')
  .attr('x', (d) => (d.children ? -6 : 6))
  .attr('text-anchor', (d) =>
    d.children ? 'end' : 'start',
  )
  .text((d) => d.data.name);
